#
# spec file for package python3-aiohttp
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python3-aiohttp
Version:        0.17.2
Release:        3.3
Url:            https://pypi.python.org/pypi/aiohttp
Summary:        Http client/server for asyncio
License:        Apache-2.0
Group:          Development/Languages/Python
Source:         https://pypi.python.org/packages/source/a/aiohttp/aiohttp-%{version}.tar.gz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  python3-chardet
BuildRequires:  python3-devel
BuildRequires:  python3-setuptools
Requires:       python3-chardet

%description
http client/server for asyncio:
* Supports both client and server side of HTTP protocol.
* Supports Web-Sockets out-of-the-box.
* Web-server has middlewares and pluggable routing.

%prep
%setup -q -n aiohttp-%{version}

%build
python3 setup.py build

%install
python3 setup.py install --prefix=%{_prefix} --root=%{buildroot}

%files
%defattr(-,root,root,-)
%doc CHANGES.txt CONTRIBUTORS.txt LICENSE.txt README.rst
%{python3_sitearch}/*

%changelog
* Tue Aug 11 2015 arun@gmx.de
- update to version 0.17.2:
  * Don’t forget to pass data argument forward #462
  * Fix multipart read bytes count #463
- changes from version 0.17.1:
  * Fix multidict comparsion to arbitrary abc.Mapping
* Mon Aug 10 2015 arun@gmx.de
- update to version 0.17.0:
  * Make StaticRoute support Last-Modified and If-Modified-Since
    headers #386
  * Add Request.if_modified_since and Stream.Response.last_modified
    properties
  * Fix deflate compression when writing a chunked response #395
  * Request`s content-length header is cleared now after redirect from
    POST method #391
  * Return a 400 if server received a non HTTP content #405
  * Fix keep-alive support for aiohttp clients #406
  * Allow gzip compression in high-level server response interface
    [#403]
  * Rename TCPConnector.resolve and family to dns_cache #415
  * Make UrlDispatcher ignore quoted characters during url matching
    [#414] Backward-compatibility warning: this may change the url matched
    by your queries if they send quoted character (like %%2F for /) #414
  * Use optional cchardet accelerator if present #418
  * Borrow loop from Connector in ClientSession if loop is not set
  * Add context manager support to ClientSession for session closing.
  * Add toplevel get(), post(), put(), head(), delete(), options(),
    patch() coroutines.
  * Fix IPv6 support for client API #425
  * Pass SSL context through proxy connector #421
  * Make the rule: path for add_route should start with slash
  * Don’t process request finishing by low-level server on closed
    event loop
  * Don’t override data if multiple files are uploaded with same key
    [#433]
  * Ensure multipart.BodyPartReader.read_chunk read all the necessary
    data to avoid false assertions about malformed multipart payload
  * Dont sent body for 204, 205 and 304 http exceptions #442
  * Correctly skip Cython compilation in MSVC not found #453
  * Add response factory to StaticRoute #456
  * Don’t append trailing CRLF for multipart.BodyPartReader #454
* Sat Jul 18 2015 arun@gmx.de
- update to version 0.16.6:
  * Skip compilation on Windows if vcvarsall.bat cannot be found #438
* Sun Jun 14 2015 arun@gmx.de
- update to version 0.16.5:
  * Get rid of all comprehensions and yielding in _multidict #410
- changes from version 0.16.4:
  * Don't clear current exception in multidict's __repr__ (cythonized versions) #410
* Sun May 31 2015 arun@gmx.de
- update to version 0.16.3:
  * Fix StaticRoute vulnerability to directory traversal attacks #380
* Sat May 30 2015 arun@gmx.de
- update to version 0.16.2:
  * Update python version required for __del__ usage: it’s actially
    3.4.1 instead of 3.4.0
  * Add check for presence of loop.is_closed() method before call the
    former #378
- changes from version 0.16.1:
  * Fix regression in static file handling #377
- changes from version 0.16.0:
  * Unset waiter future after cancellation #363
  * Update request url with query parameters #372
  * Support new fingerprint param of TCPConnector to enable verifying
    ssl certificates via md5, sha1, or sha256 digest #366
  * Setup uploaded filename if field value is binary and transfer
    encoding is not specified #349
  * Implement ClientSession.close() method
  * Implement connector.closed readonly property
  * Implement ClientSession.closed readonly property
  * Implement ClientSession.connector readonly property
  * Implement ClientSession.detach method
  * Add __del__ to client-side objects: sessions, connectors,
    connections, requests, responses.
  * Refactor connections cleanup by connector #357
  * Add limit parameter to connector constructor #358
  * Add request.has_body property #364
  * Add response_class parameter to ws_connect() #367
  * ProxyConnector doesn’t support keep-alive requests by default
    starting from now #368
  * Add connector.force_close property
  * Add ws_connect to ClientSession #374
  * Support optional chunk_size parameter in router.add_static()
* Mon Apr 27 2015 arun@gmx.de
- specfile:
  * added python3-chardet dependency
* Thu Apr 23 2015 arun@gmx.de
- update to version 0.15.3:
  * Fix graceful shutdown handling
  * Fix Expect header handling for not found and not allowed routes
    [#340]
* Wed Apr 22 2015 arun@gmx.de
- update to version 0.15.2:
  * Flow control subsystem refactoring
  * Http server performace optimizations
  * Allow to match any request method with *
  * Explicitly call drain on transport #316
  * Make chardet module dependency mandatory #318
  * Support keep-alive for HTTP 1.0 #325
  * Do not chunk single file during upload #327
  * Add ClientSession object for cookie storage and default headers
    [#328]
  * Add keep_alive_on argument for http server handler.
* Fri Apr  3 2015 arun@gmx.de
- update to version 0.15.1:
  * Pass Autobahn Testsuit tests
  * Fixed websocket fragmentation
  * Fixed websocket close procedure
  * Fixed parser buffer limits
  * Added timeout parameter to WebSocketResponse ctor
  * Added WebSocketResponse.close_code attribute
* Sat Mar 28 2015 arun@gmx.de
- update to version 0.15.0:
  * Client WebSockets support
  * New Multipart system #273
  * Support for “Except” header #287 #267
  * Set default Content-Type for post requests #184
  * Fix issue with construction dynamic route with regexps and
    trailing slash #266
  * Add repr to web.Request
  * Add repr to web.Response
  * Add repr for NotFound and NotAllowed match infos
  * Add repr for web.Application
  * Add repr to UrlMappingMatchInfo #217
  * Gunicorn 19.2.x compatibility
* Wed Mar  4 2015 andrea@opensuse.org
- Fixed download url so that the package can be submitted into Factory
* Sat Feb 28 2015 andrea@opensuse.org
- new package
